# Egritools

A personal utility toolkit developed by Christopher (Egrigor86).

Includes:
- Change file extensions
- Create Python virtual environments
- Upload datasets to HuggingFace
- Preclean JSON arrays
- Offline Python wheel manager
- GPT2 Trainer


Updated to include new tools. Readme update on to do list.